      real function redgauss(e1, e0, sigma, red_sigma)
c
c Returns the unormalised value of a Gaussian with a red tail. This is
c modelled simply by having an additive second Gaussian when e1 < e0.
c The second Gaussian has a width = sigma*red_sigma
c
      implicit none

c  Local Variables
      real e1, e0, sigma, sigma2, red_sigma
      real var1, var2, comp1, comp2

c  Local Constants
      real dsq2pi
      parameter(dsq2pi = 2.50662827463)
      real threshold
      parameter (threshold = 23.0)

c  External Functions

c  Common Parameters

c-
      if (e1 .ge. e0) then
          var1 = ((e1-e0)/sigma)**2
          if( var1 .lt. threshold ) then
              redgauss = (1.0/(sigma*dsq2pi)) * exp(-0.5 * var1)
          else
              redgauss = 0.0
          endif
      else
          sigma2 = sigma * red_sigma
          var1 = ((e1-e0)/sigma)**2
          var2 = ((e1-e0)/sigma2)**2
          if( var1 .lt. threshold ) then
              comp1 = (1.0/(sigma*dsq2pi)) * exp(-0.5 * var1)
          else
              comp1 = 0.0
          endif
          if( var2 .lt. threshold ) then
              comp2 = (1.0/(sigma2*dsq2pi)) * exp(-0.5 * var2)
          else
              comp2 = 0.0
          endif
          redgauss = (sigma2 / (sigma+sigma2)) * (comp1 + comp2)
      endif

      return
      end





