      real function spread_function(e)

      implicit none

c  Local variables
      real e, sigma, var

c Local constants
      real threshold
      parameter (threshold = 23.0)

      common /spread_sigma/ sigma

      var = (e/sigma)**2
      if( var .lt. threshold ) then
          spread_function = exp(-0.5 * var)
      else
          spread_function = 0.0
      endif

      return
      end


      real function shelf(e1, main_energy, main_sigma, shelf_emin)
c
c  Returns the un-normalised level of the low-energy shelf at energy e1. This 
c  is modelled by assuming a uniform energy loss between 
c             shelf_emin <= e1 <= main_energy
c
c  convolved with a Gaussian spread function of width, main_sigma
c
      implicit none

c  Local Variables
      real shelf_emin, main_sigma, main_energy
      real e1, elo, ehi, lolim, hilim, sigma

c  Local Constants
      integer nstep
      parameter(nstep = 100)

      real dsq2pi
      parameter(dsq2pi = 2.50662827463)

C
c  External Functions
C-UL
C-UL added explicit external function to fix compilation problem under f90
C-UL
      external spread_function
      real spread_function
      real simpson

c  Common Parameters
      common /spread_sigma/ sigma

c-
      lolim = -5.0 * main_sigma
      hilim = 5.0 * main_sigma
      elo = shelf_emin - e1
      ehi = main_energy - e1

      if((elo .lt. lolim) .and. (ehi .lt. lolim)) then
          shelf = 0.0
          return
      endif

      if((elo .gt. hilim) .and. (ehi .gt. hilim)) then
          shelf = 0.0
          return
      endif

      if((elo .lt. lolim) .and. (ehi .gt. hilim)) then
          shelf = 1.0
          return
      endif

      sigma = main_sigma
      shelf = simpson(spread_function, elo, ehi, nstep)
      shelf = shelf / (dsq2pi * main_sigma)

      return
      end


